StructuredNote

Struct StructuredNote 

pub struct StructuredNote {
Show 53 fields pub uid: String, pub figi: String, pub ticker: String, pub class_code: String, pub isin: String, pub name: String, pub asset_uid: String, pub position_uid: String, pub min_price_increment: Option<Quotation>, pub lot: i32, pub nominal: Option<MoneyValue>, pub currency: String, pub maturity_date: Option<Timestamp>, pub placement_date: Option<Timestamp>, pub issue_kind: String, pub issue_size: i32, pub issue_size_plan: i32, pub dlong_client: Option<Quotation>, pub dshort_client: Option<Quotation>, pub short_enabled_flag: bool, pub exchange: String, pub trading_status: i32, pub api_trade_available_flag: bool, pub buy_available_flag: bool, pub sell_available_flag: bool, pub limit_order_available_flag: bool, pub market_order_available_flag: bool, pub bestprice_order_available_flag: bool, pub weekend_flag: bool, pub liquidity_flag: bool, pub for_iis_flag: bool, pub for_qual_investor_flag: bool, pub pawnshop_list_flag: bool, pub real_exchange: i32, pub first_1min_candle_date: Option<Timestamp>, pub first_1day_candle_date: Option<Timestamp>, pub borrow_name: String, pub type: String, pub logic_portfolio: i32, pub asset_type: i32, pub basic_assets: Vec<BasicAsset>, pub safety_barrier: Option<Quotation>, pub coupon_period_base: String, pub observation_principle: i32, pub observation_frequency: String, pub initial_price_fixing_date: Option<Timestamp>, pub yield: Vec<Yield>, pub coupon_saving_flag: bool, pub sector: String, pub country_of_risk: String, pub country_of_risk_name: String, pub logo_name: String, pub required_tests: Vec<String>,
}
Объект передачи информации о структурной ноте.

Fields

uid: String

Уникальный идентификатор инструмента.

figi: String

FIGI-идентификатор инструмента.

ticker: String

Тикер инструмента.

class_code: String

Класс-код (секция торгов).

isin: String

ISIN-идентификатор инструмента.

name: String

Название инструмента.

asset_uid: String

Уникальный идентификатор актива.

position_uid: String

Уникальный идентификатор позиции.

min_price_increment: Option<Quotation>

Шаг цены.

lot: i32

Лотность инструмента.

nominal: Option<MoneyValue>

Номинал.

currency: String

Валюта расчетов.

maturity_date: Option<Timestamp>

Дата погашения облигации в формате UTC.

placement_date: Option<Timestamp>

Дата размещения в формате UTC.

issue_kind: String

Форма выпуска.

issue_size: i32

Размер выпуска.

issue_size_plan: i32

Плановый размер выпуска.

dlong_client: Option<Quotation>

Ставка риска клиента по инструменту лонг.

dshort_client: Option<Quotation>

Ставка риска клиента по инструменту шорт.

short_enabled_flag: bool

Признак доступности для операций в шорт.

exchange: String

Торговая площадка (секция биржи).

trading_status: i32

Текущий режим торгов инструмента.

api_trade_available_flag: bool

Признак доступности торгов по бумаге через API.

buy_available_flag: bool

Признак доступности для покупки.

sell_available_flag: bool

Признак доступности для продажи.

limit_order_available_flag: bool

Признак доступности выставления лимитной заявки по инструменту.

market_order_available_flag: bool

Признак доступности выставления рыночной заявки по инструменту.

bestprice_order_available_flag: bool

Признак доступности выставления bestprice заявки по инструменту.

weekend_flag: bool

Флаг отображающий доступность торговли инструментом по выходным.

liquidity_flag: bool

Флаг достаточной ликвидности.

for_iis_flag: bool

Возможность покупки/продажи на ИИС.

for_qual_investor_flag: bool

Флаг отображающий доступность торговли инструментом только для квалифицированных инвесторов.

pawnshop_list_flag: bool

Признак ФИ, включенного в ломбардный список.

real_exchange: i32

Реальная площадка исполнения расчётов.

first_1min_candle_date: Option<Timestamp>

Дата первой минутной свечи.

first_1day_candle_date: Option<Timestamp>

Дата первой дневной свечи.

borrow_name: String

Название заемщика.

type: String

Тип структурной ноты.

logic_portfolio: i32

Стратегия портфеля.

asset_type: i32

Тип базового актива.

basic_assets: Vec<BasicAsset>

Базовые активы, входящие в ноту.

safety_barrier: Option<Quotation>

Барьер сохранности (в процентах).

coupon_period_base: String

Базис расчета НКД.

observation_principle: i32

Принцип наблюдений.

observation_frequency: String

Частота наблюдений.

initial_price_fixing_date: Option<Timestamp>

Дата фиксации цен базовых активов.

yield: Vec<Yield>

Доходность по ноте в годовом выражении.

coupon_saving_flag: bool

Признак сохранения купонов.

sector: String

Сектор экономики.

country_of_risk: String

Код страны рисков.

country_of_risk_name: String

Наименование страны рисков.

logo_name: String

Имя файла логотипа эмитента.

required_tests: Vec<String>

Тесты, которые необходимо пройти клиенту, чтобы совершать покупки по бумаге.

Implementations

Source

impl StructuredNote

pub fn trading_status(&self) -> SecurityTradingStatus

Returns the enum value of trading_status, or the default if the field is set to an invalid enum value.

pub fn set_trading_status(&mut self, value: SecurityTradingStatus)

Sets trading_status to the provided enum value.

pub fn real_exchange(&self) -> RealExchange

Returns the enum value of real_exchange, or the default if the field is set to an invalid enum value.

pub fn set_real_exchange(&mut self, value: RealExchange)

Sets real_exchange to the provided enum value.

pub fn logic_portfolio(&self) -> LogicPortfolio

Returns the enum value of logic_portfolio, or the default if the field is set to an invalid enum value.

pub fn set_logic_portfolio(&mut self, value: LogicPortfolio)

Sets logic_portfolio to the provided enum value.

pub fn asset_type(&self) -> AssetType

Returns the enum value of asset_type, or the default if the field is set to an invalid enum value.

pub fn set_asset_type(&mut self, value: AssetType)

Sets asset_type to the provided enum value.

pub fn observation_principle(&self) -> ObservationPrinciple

Returns the enum value of observation_principle, or the default if the field is set to an invalid enum value.

pub fn set_observation_principle(&mut self, value: ObservationPrinciple)

Sets observation_principle to the provided enum value.